==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/security/v1beta1/RequestAuthenticationListFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RequestAuthenticationListFluent<A extends RequestAuthenticationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,RequestAuthentication item);
  public A setToItems(Integer index,RequestAuthentication item);
  public A addToItems(io.fabric8.istio.api.security.v1beta1.RequestAuthentication... items);
  public A addAllToItems(Collection<RequestAuthentication> items);
  public A removeFromItems(io.fabric8.istio.api.security.v1beta1.RequestAuthentication... items);
  public A removeAllFromItems(Collection<RequestAuthentication> items);
  public A removeMatchingFromItems(Predicate<RequestAuthenticationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RequestAuthentication> getItems();
  public List<RequestAuthentication> buildItems();
  public RequestAuthentication buildItem(Integer index);
  public RequestAuthentication buildFirstItem();
  public RequestAuthentication buildLastItem();
  public RequestAuthentication buildMatchingItem(Predicate<RequestAuthenticationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<RequestAuthenticationBuilder> predicate);
  public A withItems(List<RequestAuthentication> items);
  public A withItems(io.fabric8.istio.api.security.v1beta1.RequestAuthentication... items);
  public Boolean hasItems();
  public RequestAuthenticationListFluent.ItemsNested<A> addNewItem();
  public RequestAuthenticationListFluent.ItemsNested<A> addNewItemLike(RequestAuthentication item);
  public RequestAuthenticationListFluent.ItemsNested<A> setNewItemLike(Integer index,RequestAuthentication item);
  public RequestAuthenticationListFluent.ItemsNested<A> editItem(Integer index);
  public RequestAuthenticationListFluent.ItemsNested<A> editFirstItem();
  public RequestAuthenticationListFluent.ItemsNested<A> editLastItem();
  public RequestAuthenticationListFluent.ItemsNested<A> editMatchingItem(Predicate<RequestAuthenticationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,RequestAuthenticationFluent<RequestAuthenticationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/RequestAuthenticationListFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RequestAuthenticationListFluent<A extends RequestAuthenticationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,RequestAuthentication item);
  public A setToItems(int index,RequestAuthentication item);
  public A addToItems(io.fabric8.istio.api.security.v1beta1.RequestAuthentication... items);
  public A addAllToItems(Collection<RequestAuthentication> items);
  public A removeFromItems(io.fabric8.istio.api.security.v1beta1.RequestAuthentication... items);
  public A removeAllFromItems(Collection<RequestAuthentication> items);
  public A removeMatchingFromItems(Predicate<RequestAuthenticationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RequestAuthentication> getItems();
  public List<RequestAuthentication> buildItems();
  public RequestAuthentication buildItem(int index);
  public RequestAuthentication buildFirstItem();
  public RequestAuthentication buildLastItem();
  public RequestAuthentication buildMatchingItem(Predicate<RequestAuthenticationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<RequestAuthenticationBuilder> predicate);
  public A withItems(List<RequestAuthentication> items);
  public A withItems(io.fabric8.istio.api.security.v1beta1.RequestAuthentication... items);
  public Boolean hasItems();
  public RequestAuthenticationListFluent.ItemsNested<A> addNewItem();
  public RequestAuthenticationListFluent.ItemsNested<A> addNewItemLike(RequestAuthentication item);
  public RequestAuthenticationListFluent.ItemsNested<A> setNewItemLike(int index,RequestAuthentication item);
  public RequestAuthenticationListFluent.ItemsNested<A> editItem(int index);
  public RequestAuthenticationListFluent.ItemsNested<A> editFirstItem();
  public RequestAuthenticationListFluent.ItemsNested<A> editLastItem();
  public RequestAuthenticationListFluent.ItemsNested<A> editMatchingItem(Predicate<RequestAuthenticationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,RequestAuthenticationFluent<RequestAuthenticationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
